%global __requires_exclude pkg-config

Summary: System and Service Manager
Name: systemd
Version: 253
Release: 5%{?dist}.2
License: LGPLv2+ and MIT and GPLv2+
Url: https://www.freedesktop.org/wiki/Software/systemd
Source0: https://github.com/systemd/systemd/archive/v%{version}/%{name}-%{version}.tar.gz

Source1: split-files.py
Source2: purge-nobody-user
Source3: yum-protect-systemd.conf
Source4: inittab
Source5: sysctl.conf.README
Source6: systemd-journal-remote.xml
Source7: systemd-journal-gatewayd.xml
Source8: 20-yama-ptrace.conf
Source9: systemd-udev-trigger-no-reload.conf
Source10: 20-grubby.install
Source11: systemd-user
Source12: libsystemd-shared.abignore

Source13: 10-oomd-defaults.conf
Source14: 10-oomd-root-slice-defaults.conf
Source15: 10-oomd-user-service-defaults.conf
Source16: disable-privatedevices.conf

Source21: macros.sysusers
Source22: sysusers.attr
Source23: sysusers.prov
Source24: sysusers.generate-pre.sh

Patch0001: CVE-2023-31438.patch
Patch0002: CVE-2023-31439.patch

Patch3000: use-bfq-scheduler.patch

Patch5000: proc-dont-trigger-mount-error-with-invalid-options-o.patch
Patch5001: fix-unsupport-memory-recursiveprot.patch

%ifarch x86_64 aarch64
%global have_gnu_efi 1
%endif

BuildRequires:  gcc, gcc-c++, coreutils, meson >= 0.43
BuildRequires:  libcap-devel, libmount-devel, libfdisk-devel, dbus-devel, libblkid-devel, /usr/sbin/sfdisk
BuildRequires:  cryptsetup-devel, libgcrypt-devel, pam-devel, libselinux-devel, openssl-devel, audit-libs-devel
BuildRequires:  libseccomp-devel, valgrind-devel
BuildRequires:  libgpg-error-devel, gnutls-devel, pkgconfig(tss2-esys), pkgconfig(tss2-rc), pkgconfig(tss2-mu)
BuildRequires:  acl, libacl-devel, gobject-introspection-devel, libcurl-devel, libidn2-devel, hostname, gperf, pkgconfig
BuildRequires:  xz-devel, xz, lz4-devel, lz4, bzip2-devel, libzstd-devel, libzstd-devel
BuildRequires:  kmod-devel,elfutils-devel, iptables-devel, firewalld-filesystem
BuildRequires:  systemtap-sdt-devel, tree
BuildRequires:  libxslt, docbook-style-xsl, gawk, gettext
BuildRequires:  python3dist(lxml), python3dist(jinja2), pkgconfig(bash-completion), perl, perl(IPC::SysV)
%if 0%{?have_gnu_efi}
BuildRequires:  gnu-efi gnu-efi-devel
%endif

Requires(post): coreutils
Requires(post): grep
Requires(post): openssl-libs
Requires:       dbus >= 1.9.18
Requires:       %{name}-pam = %{version}-%{release}
Requires:       (%{name}-rpm-macros = %{version}-%{release} if rpm-build)
Requires:       %{name}-libs = %{version}-%{release}
Requires:       util-linux-core
Provides:       /bin/systemctl, /sbin/shutdown, syslog, systemd-units = %{version}-%{release}
Provides:       system-setup-keyboard = 0.9, systemd-sysv = 206, timedatex = 0.6-3

Recommends:     diffutils
Recommends:     %{name}-resolved = %{version}-%{release}
Recommends:     %{name}-networkd = %{version}-%{release}
Recommends:     libidn2.so.0()(64bit)
Recommends:     libidn2.so.0(IDN2_0.0.0)(64bit)
Recommends:     libdw.so.1()(64bit)
Recommends:     libdw.so.1(ELFUTILS_0.186)(64bit)
Recommends:     libelf.so.1()(64bit)
Recommends:     libelf.so.1(ELFUTILS_1.7)(64bit)

%description
systemd is a system and service manager that runs as PID 1 and starts the rest
of the system. It provides aggressive parallelization capabilities, uses socket
and D-Bus activation for starting services, offers on-demand starting of
daemons, keeps track of processes using Linux control groups, maintains mount
and automount points, and implements an elaborate transactional dependency-based
service control logic. systemd supports SysV and LSB init scripts and works as a
replacement for sysvinit. Other parts of this package are a logging daemon,
utilities to control basic system configuration like the hostname, date, locale,
maintain a list of logged-in users, system accounts, runtime directories and
settings, and a logging daemons.

%package libs
Summary:        systemd libraries
License:        LGPLv2+ and MIT
Provides:       nss-myhostname = 0.4

%description libs
This package provides libraries for systemd and udev.

%package pam
Summary:        systemd PAM module
Requires:       %{name} = %{version}-%{release}

%description pam
This package provides PAM support with systemd-logind.

%package rpm-macros
Summary:        Macros that define paths and scriptlets related to systemd
BuildArch:      noarch

%description rpm-macros
This package provides the systemd-related macros.

%package devel
Summary:        Development headers for systemd
License:        LGPLv2+ and MIT
Requires:       %{name}-libs = %{version}-%{release}
Requires:       %{name}-pam = %{version}-%{release}
Provides:       libudev-devel = %{version}

%description devel
This package provides headers and auxiliary files for developers who need to use
libudev or libsystemd.

%package udev
Summary: Rule-based device node and kernel event manager
License:        LGPLv2+
Requires:       systemd = %{version}-%{release}
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
Requires(post): grep
Requires:       kmod >= 18-4
Requires:       kbd
Provides:       udev = %{version}
Provides:       udev = %{version}
Provides:       u2f-hidraw-policy = 1.0.2-40

Recommends:     libelf.so.1()(64bit)
Recommends:     libelf.so.1(ELFUTILS_1.7)(64bit)
Recommends:     libdw.so.1()(64bit)
Recommends:     libdw.so.1(ELFUTILS_0.186)(64bit)
Recommends:     libtss2-esys.so.0()(64bit)
Recommends:     libtss2-mu.so.0()(64bit)
Recommends:     libtss2-rc.so.0()(64bit)
Suggests:       systemd-bootchart


%description udev
systemd-udevd listens to kernel uevents. For every event, systemd-udevd
executes matching instructions specified in udev rules.The behavior of the daemon
can be configured using udev.conf, its command line options, environment variables,
and on the kernel command line, or changed dynamically with udevadm control.
This package also provides systemd-timesyncd, a network time protocol daemon.

%package container
# Name is the same as in Debian
Summary: Tools for containers and VMs
License:        LGPLv2+
Requires:       %{name} = %{version}-%{release}

%description container
This package provides tools to manage containers and virtual machines.


%package journal-remote
Summary:        Tools to send journal events over the network
License:        LGPLv2+
Requires:       %{name} = %{version}-%{release}
Requires(pre):    /usr/bin/getent
Requires:       firewalld-filesystem
Provides:       %{name}-journal-gateway = %{version}-%{release}

%description journal-remote
This package provides the ability for programs to read and write journal files
through network, with encrypted HTTP.

%package networkd
Summary:        System daemon that manages network configurations
License:        LGPLv2+
Requires:       %{name} = %{version}-%{release}

%description networkd
systemd-networkd is a system service that manages networks. It detects and
configures network devices as they appear, as well as creating virtual network
devices.

%package resolved
Summary:        Network Name Resolution manager
Requires:       %{name} = %{version}-%{release}
Requires:       libidn2.so.0()(64bit)
Requires:       libidn2.so.0(IDN2_0.0.0)(64bit)
Requires(posttrans): grep

%description resolved
systemd-resolved is a system service that provides network name
resolution to local applications. It implements a caching and
validating DNS/DNSSEC stub resolver, as well as an LLMNR and
MulticastDNS resolver and responder.

%package oomd-defaults
Summary:        Configuration files for systemd-oomd
Requires:       %{name} = %{version}-%{release}
License:        LGPLv2+
BuildArch:      noarch

%description oomd-defaults
This package provides a system service that uses cgroups-v2 and
pressure stall information (PSI) to monitor and take corrective
action before an OOM occurs in the kernel space.

%package tests
Summary:       Internal unit tests for systemd
Requires:      %{name} = %{version}-%{release}
License:       LGPLv2+

%description tests
This package provides some built-in tests which can be run to test the
systemd internals.

%prep
%autosetup -n %{name}-%{version} -p1

cp %{SOURCE11} src/login/systemd-user.in

%build

CONFIGURE_OPTS=(
        -Dmode=release
        -Dsysvinit-path=/etc/rc.d/init.d
        -Drc-local=/etc/rc.d/rc.local
        -Duser-path=/usr/local/bin:/usr/local/sbin:/usr/bin:/usr/sbin
        -Dservice-watchdog=
        -Ddev-kvm-mode=0666
        -Dkmod=true
        -Dblkid=true
        -Dfdisk=true
        -Dseccomp=true
        -Dselinux=true
        -Dpolkit=true
        -Dxz=true
        -Dzlib=true
        -Dbzip2=true
        -Dlz4=true
        -Dzstd=true
        -Dpam=true
        -Dacl=true
        -Dopenssl=true
        -Dcryptolib=openssl
        -Dp11kit=true
        -Dgcrypt=true
        -Daudit=true
        -Delfutils=true
        -Dlibcryptsetup=true
        -Dgnutls=true
        -Dlibidn2=true
        -Dlibcurl=true
        -Defi=true
        -Dgnu-efi=%[%{?have_gnu_efi}?"true":"false"]
        -Dtpm=true
        -Dtpm2=true
        -Dhwdb=true
        -Dsysusers=true
        -Ddefault-kill-user-processes=false
        -Dtests=unsafe
        -Dinstall-tests=true
        -Dtty-gid=5
        -Dusers-gid=100
        -Dnobody-user=nobody
        -Dnobody-group=nobody
        -Dsplit-usr=false
        -Dsplit-bin=true
        -Db_lto=true
        -Db_ndebug=false
        -Dman=true
        -Dversion-tag=v%{version}-%{release}
        -Ddefault-dnssec=no
        -Ddefault-dns-over-tls=no
        -Ddefault-mdns=no
        -Ddefault-llmnr=resolve
        -Dstatus-unit-format-default=combined
        -Doomd=true
)


%meson "${CONFIGURE_OPTS[@]}"
%meson_build

%install
%meson_install

%global system_unit_dir %{_prefix}/lib/systemd/system

install -d %{buildroot}/%{_sbindir}
ln -sf ../bin/udevadm %{buildroot}%{_sbindir}/udevadm

touch %{buildroot}/etc/crypttab
chmod 600 %{buildroot}/etc/crypttab

install -Dm0644 %{SOURCE4} %{buildroot}/etc/
install -Dm0644 %{SOURCE5} %{buildroot}/etc/sysctl.conf
ln -s ../sysctl.conf %{buildroot}/etc/sysctl.d/99-sysctl.conf

install -d %{buildroot}%{system_unit_dir}/basic.target.wants
install -d %{buildroot}%{system_unit_dir}/default.target.wants
install -d %{buildroot}%{system_unit_dir}/dbus.target.wants
install -d %{buildroot}%{system_unit_dir}/syslog.target.wants
install -d %{buildroot}/run
touch %{buildroot}/run/utmp
install -d %{buildroot}%{_localstatedir}/log
touch %{buildroot}%{_localstatedir}/log/lastlog
touch %{buildroot}%{_localstatedir}/log/{w,b}tmp
chmod 0664 %{buildroot}%{_localstatedir}/log/lastlog

install -d %{buildroot}%{_prefix}/lib/systemd/system-generators
install -d %{buildroot}%{_prefix}/lib/systemd/user-generators
install -d %{buildroot}%{_prefix}/lib/systemd/system-shutdown/
install -d %{buildroot}%{_prefix}/lib/systemd/system-sleep/

touch %{buildroot}%{_sysconfdir}/hostname
touch %{buildroot}%{_sysconfdir}/vconsole.conf
touch %{buildroot}%{_sysconfdir}/locale.conf
touch %{buildroot}%{_sysconfdir}/machine-id
touch %{buildroot}%{_sysconfdir}/machine-info
touch %{buildroot}%{_sysconfdir}/localtime
install -d %{buildroot}%{_sysconfdir}/X11/xorg.conf.d
touch %{buildroot}%{_sysconfdir}/X11/xorg.conf.d/00-keyboard.conf
touch %{buildroot}%{_sysconfdir}/udev/hwdb.bin

install -d %{buildroot}%{_localstatedir}/lib/systemd/{coredump,catalog,backlight,rfkill,linger,timesync,private}
install -d %{buildroot}%{_localstatedir}/lib/private/systemd/journal-upload
install -d %{buildroot}%{_localstatedir}/log/{private,journal}
install -d %{buildroot}%{_localstatedir}/cache/private
install -d %{buildroot}%{system_unit_dir}/systemd-udev-trigger.service.d
install -d %{buildroot}%{system_unit_dir}/{-.slice.d,user@.service.d,systemd-hostnamed.service.d}
install -d %{buildroot}%{_prefix}/lib/systemd/oomd.conf.d
install -d %{buildroot}%{_rpmconfigdir}/{macros.d,fileattrs}
install -d %{buildroot}/usr/lib/firewalld/services
ln -s ../private/systemd/journal-upload %{buildroot}%{_localstatedir}/lib/systemd/journal-upload
touch %{buildroot}%{_localstatedir}/lib/systemd/catalog/database
touch %{buildroot}%{_localstatedir}/lib/systemd/random-seed
touch %{buildroot}%{_localstatedir}/lib/systemd/timesync/clock
touch %{buildroot}%{_localstatedir}/lib/private/systemd/journal-upload/state

install -Dm0644 %{SOURCE3} %{buildroot}/etc/dnf/protected.d/systemd.conf
install -Dm0644 %{SOURCE6} %{SOURCE7} %{buildroot}/usr/lib/firewalld/services/
install -Dm0644 %{SOURCE8} %{buildroot}%{_pkgdocdir}/
install -Dm0644 %{SOURCE9} %{buildroot}%{system_unit_dir}/systemd-udev-trigger.service.d/
install -Dm0644 %{SOURCE14} %{buildroot}%{system_unit_dir}/-.slice.d/
install -Dm0644 %{SOURCE15} %{buildroot}%{system_unit_dir}/user@.service.d/
install -Dm0644 %{SOURCE16} %{buildroot}%{system_unit_dir}/systemd-hostnamed.service.d/

install -Dm0755 %{SOURCE10} %{buildroot}%{_prefix}/lib/kernel/install.d/
install -Dm0644 %{SOURCE12} %{buildroot}%{_prefix}/lib/systemd/
install -D %{SOURCE2} %{buildroot}%{_prefix}/lib/systemd/
install -Dm0644 %{SOURCE13} %{buildroot}%{_prefix}/lib/systemd/oomd.conf.d/

install -Dm0644 %{SOURCE21} %{buildroot}%{_rpmconfigdir}/macros.d/
install -Dm0644 %{SOURCE22} %{buildroot}%{_rpmconfigdir}/fileattrs/
install -Dm0755 %{SOURCE23} %{buildroot}%{_rpmconfigdir}/
install -Dm0755 %{SOURCE24} %{buildroot}%{_rpmconfigdir}/

# we use preset fin release, instead of this.
rm -f %{buildroot}%{_prefix}/lib/systemd/system-preset/90-systemd.preset

%find_lang %{name}

%{__python3} %{SOURCE1} %buildroot <<EOF
%ghost %config(noreplace) /etc/crypttab
%ghost /etc/udev/hwdb.bin
/etc/inittab
/usr/lib/systemd/purge-nobody-user
%ghost %config(noreplace) /etc/vconsole.conf
%ghost %config(noreplace) /etc/X11/xorg.conf.d/00-keyboard.conf
%ghost %attr(0664,root,root) %verify(not group) /run/utmp
%ghost %attr(0664,root,root) %verify(not group) /var/log/wtmp
%ghost %attr(0660,root,root) %verify(not group) /var/log/btmp
%ghost %attr(0664,root,root) %verify(not md5 size mtime group) /var/log/lastlog
%ghost %config(noreplace) /etc/hostname
%ghost %config(noreplace) /etc/localtime
%ghost %config(noreplace) /etc/locale.conf
%ghost %attr(0444,root,root) %config(noreplace) /etc/machine-id
%ghost %config(noreplace) /etc/machine-info
%ghost %attr(0700,root,root) %dir /var/cache/private
%ghost %attr(0700,root,root) %dir /var/lib/private
%ghost %dir /var/lib/private/systemd
%ghost %dir /var/lib/private/systemd/journal-upload
%ghost /var/lib/private/systemd/journal-upload/state
%ghost %dir /var/lib/systemd/timesync
%ghost /var/lib/systemd/timesync/clock
%ghost %dir /var/lib/systemd/backlight
%ghost /var/lib/systemd/catalog/database
%ghost %dir /var/lib/systemd/coredump
%ghost /var/lib/systemd/journal-upload
%ghost %dir /var/lib/systemd/linger
%ghost /var/lib/systemd/random-seed
%ghost %dir /var/lib/systemd/rfkill
%ghost %dir %verify(not mode group) /var/log/journal
%ghost %dir /var/log/journal/remote
%ghost %attr(0700,root,root) %dir /var/log/private
EOF

%check
meson test -C %{_vpath_builddir} -t 6 --print-errorlogs

%transfiletriggerin -P 900900 -- /usr/lib/systemd/system /etc/systemd/system
/usr/lib/systemd/systemd-update-helper system-reload-restart || :

%transfiletriggerin -P 900899 -- /usr/lib/systemd/user /etc/systemd/user
if selinuxenabled &>/dev/null; then
  /usr/lib/systemd/systemd-update-helper user-reload-restart 2>/dev/null || :
else
  /usr/lib/systemd/systemd-update-helper user-reload-restart || :
fi

%transfiletriggerun -- /usr/lib/systemd/system /etc/systemd/system
if test -d "/run/systemd/system"; then
    mkdir -p "%{_localstatedir}/lib/rpm-state/systemd"
    touch "%{_localstatedir}/lib/rpm-state/systemd/needs-reload"
fi

%filetriggerpostun -P 1000100 -- /usr/lib/systemd/system /etc/systemd/system
if test -f "%{_localstatedir}/lib/rpm-state/systemd/needs-reload"; then
    rm -rf "%{_localstatedir}/lib/rpm-state/systemd"
    /usr/lib/systemd/systemd-update-helper system-reload || :
fi

%transfiletriggerin -P 1000700 -- /usr/lib/sysusers.d
if test -d "/run/systemd/system"; then
  systemd-sysusers || :
fi

%transfiletriggerin -P 1000700 udev -- /usr/lib/udev/hwdb.d
if test -d "/run/systemd/system"; then
  systemd-hwdb update || :
fi

%transfiletriggerin -P 1000700 -- /usr/lib/systemd/catalog
if test -d "/run/systemd/system"; then
  journalctl --update-catalog || :
fi

%transfiletriggerin -P 1000700 -- /usr/lib/binfmt.d
if test -d "/run/systemd/system"; then
  /usr/lib/systemd/systemd-binfmt || :
fi

%transfiletriggerin -P 1000600 -- /usr/lib/tmpfiles.d
if test -d "/run/systemd/system"; then
  systemd-tmpfiles --create || :
fi

%transfiletriggerin -P 1000600 udev -- /usr/lib/udev/rules.d
if test -e /run/udev/control; then
  udevadm control --reload || :
fi

%transfiletriggerin -P 1000500 -- /usr/lib/sysctl.d
if test -d "/run/systemd/system"; then
  /usr/lib/systemd/systemd-sysctl || :
fi

%post
systemd-machine-id-setup &>/dev/null || :
systemctl daemon-reexec &>/dev/null ||:
journalctl --update-catalog || :
systemd-sysusers || :
systemd-tmpfiles --create &>/dev/null || :
systemctl preset-all &>/dev/null || :
systemctl --global preset-all &>/dev/null || :

%postun
if [ $1 -eq 1 ]; then
   [ -w %{_localstatedir} ] && journalctl --update-catalog || :
   systemd-tmpfiles --create &>/dev/null || :
fi

%systemd_postun_with_restart systemd-journald.service systemd-userdbd.service systemd-oomd.service


%global udev_services systemd-udev{d,-settle,-trigger}.service systemd-udevd-{control,kernel}.socket systemd-timesyncd.service %{?have_gnu_efi:systemd-boot-update.service}

%post udev
mv %{_localstatedir}/lib/random-seed %{_localstatedir}/lib/systemd/random-seed &>/dev/null
mv %{_localstatedir}/lib/backlight %{_localstatedir}/lib/systemd/backlight &>/dev/null
if [ -L %{_localstatedir}/lib/systemd/timesync ]; then
    rm %{_localstatedir}/lib/systemd/timesync
    mv %{_localstatedir}/lib/private/systemd/timesync %{_localstatedir}/lib/systemd/timesync
fi
if [ -f %{_localstatedir}/lib/systemd/clock ] ; then
    mkdir -p %{_localstatedir}/lib/systemd/timesync
    mv %{_localstatedir}/lib/systemd/clock %{_localstatedir}/lib/systemd/timesync/.
fi

udevadm hwdb --update &>/dev/null

%systemd_post %udev_services

/usr/lib/systemd/systemd-random-seed save || :

if [ -f %{_sysconfdir}/vconsole.conf ]; then
sed -i.rpm.bak -r 's/^KEYMAP="?fi-latin[19]"?/KEYMAP="fi"/' /etc/vconsole.conf || :
fi

%preun udev
%systemd_preun %udev_services

%postun udev
%systemd_postun_with_restart systemd-udevd.service systemd-timesyncd.service


%post journal-remote
%global journal_remote_units_restart systemd-journal-gatewayd.service systemd-journal-remote.service systemd-journal-upload.service
%global journal_remote_units_norestart systemd-journal-gatewayd.socket systemd-journal-remote.socket
%systemd_post %journal_remote_units_restart %journal_remote_units_norestart
%firewalld_reload

%preun journal-remote
%systemd_preun %journal_remote_units_restart %journal_remote_units_norestart
if [ $1 -eq 1 ] ; then
    if [ -f %{_localstatedir}/lib/systemd/journal-upload/state -a ! -L %{_localstatedir}/lib/systemd/journal-upload ] ; then
        mkdir -p %{_localstatedir}/lib/private/systemd/journal-upload
        mv %{_localstatedir}/lib/systemd/journal-upload/state %{_localstatedir}/lib/private/systemd/journal-upload/.
        rmdir %{_localstatedir}/lib/systemd/journal-upload || :
    fi
fi

%postun journal-remote
%systemd_postun_with_restart %journal_remote_units_restart

%post networkd
%systemd_post systemd-networkd.service systemd-networkd-wait-online.service

%preun networkd
%systemd_preun systemd-networkd.service systemd-networkd-wait-online.service

%preun resolved
if [ $1 -eq 0 ] ; then
    systemctl disable --quiet systemd-resolved.service >/dev/null || :
    if ! test -e /etc/resolv.conf; then
        ln -fsv ../run/NetworkManager/resolv.conf /etc/resolv.conf
    fi
fi

%post resolved
[ $1 -gt 1 ] || %systemd_post systemd-resolved.service

%posttrans resolved
# with networkmanager installed, /etc/resolv.conf will automatically be created.
if systemctl -q is-enabled systemd-resolved.service &>/dev/null &&
   ! systemd-analyze cat-config systemd/resolved.conf 2>/dev/null |
        grep -iqE '^DNSStubListener\s*=\s*(no?|false|0|off)\s*$'; then

  if ! test -e /etc/resolv.conf && ! test -L /etc/resolv.conf; then
    ln -sv ../run/systemd/resolve/stub-resolv.conf /etc/resolv.conf || :
  fi
fi

%global _docdir_fmt %{name}

%files -f %{name}.lang -f .file-list-main
%license LICENSE.GPL2 LICENSE.LGPL2.1
%license LICENSES/MIT.txt
%doc %{_pkgdocdir}
%exclude %{_pkgdocdir}/LICENSE*
%ghost %dir %attr(0755,-,-) /etc/systemd/system/basic.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/bluetooth.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/default.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/getty.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/graphical.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/local-fs.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/machines.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/multi-user.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/network-online.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/printer.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/remote-fs.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/sockets.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/sysinit.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/system-update.target.wants
%ghost %dir %attr(0755,-,-) /etc/systemd/system/timers.target.wants
%ghost %dir %attr(0700,-,-) /var/lib/portables
%ghost %dir %attr(0755,-,-) /var/lib/rpm-state/systemd

%files libs -f .file-list-libs
%license LICENSE.LGPL2.1

%files pam -f .file-list-pam

%files rpm-macros -f .file-list-rpm-macros

%files resolved -f .file-list-resolve

%files devel -f .file-list-devel

%files udev -f .file-list-udev

%files container -f .file-list-container
%ghost %dir %attr(0700,-,-) /var/lib/machines

%files journal-remote -f .file-list-remote

%files networkd -f .file-list-networkd

%files oomd-defaults -f .file-list-oomd-defaults

%files tests -f .file-list-tests

%changelog
* Thu Jan 25 2024 Xin Cheng <denisecheng@tencent.com> - 253-5.2
- add systemd-resolved and remove KillSignal in rc-local.service

* Fri Nov 17 2023 Xin Cheng <denisecheng@tencent.com> - 253-5.1
- remove systemd-resolved and add KillSignal in rc-local.service

* Thu Oct 19 2023 cunshunxia <cunshunxia@tencent.com> - 253-5
- fix CVE-2023-31439 and CVE-2023-31438.

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 253-4
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 253-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 18 2023 cunshunxia <cunshunxia@tencent.com> - 253-2
- Rebuilt for tpm2-tss 4.0.1

* Tue Jul 11 2023 cunshunxia <cunshunxia@tencent.com> - 253-1
- upgrade to v253.

* Tue May 30 2023 cunshunxia <cunshunxia@tencent.com> - 251-12
- fix vconsole error message when systemd update.

* Wed May 10 2023 cunshunxia <cunshunxia@tencent.com> - 251-11
- add note for posttrans of systemd-resolved.

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 251-10
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Apr 21 2023 cunshunxia <cunshunxia@tencent.com> - 251-9
- move lib-core from devel into main pkg.

* Fri Apr 21 2023 cunshunxia <cunshunxia@tencent.com> - 251-8
- remove preset file in systemd.

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 251-7
- Rebuilt for OpenCloudOS Stream 23

* Sun Jan 8 2023 cunshunxia <cunshunxia@tencent.com> - 251-6
- fix resolv.conf cannot be used after anaconda installed.

* Tue Dec 20 2022 cunshunxia <cunshunxia@tencent.com> - 251-5
- fix warning "cgroup2: Unknown parameter 'memory_recursiveprot'"

* Tue Dec 20 2022 cunshunxia <cunshunxia@tencent.com> - 251-4
- dont trigger mount error with invalid options on old kernels.

* Mon Dec 19 2022 cunshunxia <cunshunxia@tencent.com> - 251-3
- work around transfiletrigger problem.

* Fri Dec 9 2022 cunshunxia <cunshunxia@tencent.com> - 251-2
- fix meson build with optimization plain

* Mon Jun 6 2022 cunshunxia <cunshunxia@tencent.com> - 251-1
- initial build
